package com.srs.comprehensive.mapper;

import java.util.List;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.srs.comprehensive.domain.SrsMajors;
import com.srs.framework.mybatisplusMapper.EasyBaseMapper;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;

/**
 * 【请填写功能名称】Mapper接口
 * 
 * @author srs
 * @date 2023-06-27
 */
@Mapper
public interface SrsMajorsMapper extends EasyBaseMapper<SrsMajors>
{
    /**
     * 查询【请填写功能名称】
     * 
     * @param majorId 【请填写功能名称】主键
     * @return 【请填写功能名称】
     */
    public SrsMajors selectSrsMajorsByMajorId(Long majorId);

    /**
     * 通过专业代码查询信息
     * @param majorCode
     * @return
     */
    public SrsMajors selectSrsMajorsByMajorCode(String majorCode);
    public List<SrsMajors> selectSrsMajorsNameList();

    /**
     * 查询专业列表
     * 
     * @param srsMajors 【专业】
     * @return 【专业】集合
     */
    public List<SrsMajors> selectSrsMajorsList(SrsMajors srsMajors);

    /**
     * 新增专业
     * 
     * @param srsMajors 【专业】
     * @return 结果
     */
    public int insertSrsMajors(SrsMajors srsMajors);

    /**
     * 修改【专业】
     * 
     * @param srsMajors 【专业】
     * @return 结果
     */
    public int updateSrsMajors(SrsMajors srsMajors);

    /**
     * 删除【专业】
     * 
     * @param majorId 【专业】主键
     * @return 结果
     */
    public int deleteSrsMajorsByMajorId(Long majorId);

    /**
     * 批量删除【专业】
     * 
     * @param majorIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteSrsMajorsByMajorIds(Long[] majorIds);

    public List<SrsMajors> selectSrsmajorsList();

    Long selectMajorId(String zydm);

    void updateSrsStudentList(@Param("studentList") List<SrsMajors> studentList);

    Long selectXYID(String xydm);
}
